﻿using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Drawing;

namespace MemDataTable_CS
{
    public class MyHeaderUIElement : HeaderUIElement
    {
        private int lineHeight;
                
        public MyHeaderUIElement(UIElement parent, HeaderBase header) : base(parent, header)
        {
        }

        private int CalculateLineHeight(int delta)
        {
            int lines = this.Header.Band.ColHeaderLines;
            this.lineHeight = Math.Abs(delta) / lines;
            return this.lineHeight;
        }
        
        public override void GetAdjustmentRange(Point point, out UIElementAdjustmentRangeParams range)
        {   
            base.GetAdjustmentRange(point, out range);

            int lineHeight = this.CalculateLineHeight(range.maxDeltaUp);
                        
            // Allow a maximum of 5 lines for the headers. 
            range.maxDeltaDown = lineHeight * (5 - this.Header.Band.ColHeaderLines);
        }

        public override void ApplyAdjustment(Point delta)
        {            
            int lineDelta = delta.Y / this.lineHeight;
            this.Header.Band.ColHeaderLines += lineDelta;
        }

        protected override bool CanStartAdjustment(MouseEventArgs e)
        {
            return base.CanStartAdjustment(e);
        }      

        public override bool SupportsUpDownAdjustmentsFromPoint(Point point)
        {
            UltraGridBand band = this.Header.Band;             

            Rectangle workRect = this.Rect;

            // adjust the left and right of the rect to allow a 
            // narrow area at the right edge of the header to
            // be used for resizing
            //
            workRect.Y = workRect.Bottom - 2;
            workRect.Height = 4;

            if (!workRect.Contains(point))
                return false;
            
            return true;
        }
    }
}
